@@ -17,6 +17,7 @@ class TestWbIntegration(BaseConfigTest):
     def test_pywb_root(self):
         resp = self.testapp.get('/pywb/')
         self._assert_basic_html(resp)
+        assert '<link rel="stylesheet" href="/static/css/base.css"' in resp.text
         assert 'Search' in resp.text
 
     def test_pywb_root_head(self):
@@ -389,9 +390,15 @@ class TestWbIntegration(BaseConfigTest):
         assert resp.status_int == 200
         assert '"data": "^"' in resp.text
 
+    def test_post_match_as_json(self, fmod):
+        # json also matches same query
+        resp = self.post_json('/pywb/20140610001255{0}/http://httpbin.org/post?foo=bar', fmod, {'data': '^'})
+        assert resp.status_int == 200
+        assert '"data": "^"' in resp.text
+
     def test_post_invalid(self, fmod):
-        # not json
-        resp = self.post_json('/pywb/20140610001255{0}/http://httpbin.org/post?foo=bar', fmod, {'data': '^'}, status=404)
+        # wrong param
+        resp = self.post('/pywb/20140610001255{0}/http://httpbin.org/post?foo=bar', fmod, {'data': '^^'}, status=404)
         assert resp.status_int == 404
 
     def test_post_referer_redirect(self, fmod):
